@@ -35,6 +35,7 @@ public class EmailPlugin {
 
 	private static final Logger _log = LoggerFactory.getLogger(EmailPlugin.class);
 	protected static final int SECONDS2WAIT = 60;
+	public static final String WRITE_ABOVE_TO_REPLY = "- Write ABOVE THIS LINE to post a reply via email, reply with empty msg to subscribe -";
 
 	private static EmailPlugin singleton;
 
@@ -55,7 +56,7 @@ public class EmailPlugin {
 		String removedMarkup = notification2Save.getDescription().replaceAll("&amp;", "&");
 		removedMarkup = removedMarkup.replaceAll("&gt;", ">");
 		removedMarkup = removedMarkup.replaceAll("&lt;", "<");
-				
+
 		if (hashtags != null && hashtags.length > 0) {
 			_log.debug("editing hyperlinks for mail client");
 			//notification2Save uri contains the absoulte path to the feed in the correct channel, e.g. /group/ustore_vre?oid=f1637958-34d0-48fc-b5ad-13b1116e389d
@@ -75,8 +76,16 @@ public class EmailPlugin {
 
 		StringBuilder body = new StringBuilder();
 
-		body.append("<body><br />")
-		.append("<div style=\"color:#000; font-size:13px; font-family:'lucida grande',tahoma,verdana,arial,sans-serif;\">")
+		body.append("<body>");
+
+		if (notification2Save.getType() == NotificationType.POST_ALERT || 
+				notification2Save.getType() == NotificationType.COMMENT || 
+				notification2Save.getType() == NotificationType.MENTION || 
+				notification2Save.getType() == NotificationType.OWN_COMMENT) {
+			body.append("<div>").append(WRITE_ABOVE_TO_REPLY).append("</div><br />");
+		}
+
+		body.append("<div style=\"color:#000; font-size:13px; font-family:'lucida grande',tahoma,verdana,arial,sans-serif;\">")
 		.append("Dear ").append(userFirstName).append(",")  //dear <user>
 		.append("<p>").append(sender).append(" ").append(removedMarkup) // has done something
 		.append(getActionLink(notification2Save, portalURL)).append("</p>")  //Goto
@@ -112,7 +121,7 @@ public class EmailPlugin {
 			}
 		}
 		_log.debug("*****removedMarkup=\n" + removedMarkup);
-		
+
 		String sender = notification2Save.getSenderFullName();
 		if (notification2Save.getType() == NotificationType.DOCUMENT_WORKFLOW_STEP_REQUEST_TASK)
 			sender = "";
@@ -122,6 +131,13 @@ public class EmailPlugin {
 
 		StringBuilder body = new StringBuilder();
 
+		if (notification2Save.getType() == NotificationType.POST_ALERT || 
+				notification2Save.getType() == NotificationType.COMMENT || 
+				notification2Save.getType() == NotificationType.MENTION || 
+				notification2Save.getType() == NotificationType.OWN_COMMENT) {
+			body.append(WRITE_ABOVE_TO_REPLY).append("\n\n");
+		}
+
 		body.append("Dear ").append(userFirstName).append(",")  //dear <user>
 		.append("\n").append(sender).append(" ").append(removedMarkup) // has done something
 		.append("\nsee: ").append(portalURL).append(notification2Save.getUri())
@@ -199,7 +215,7 @@ public class EmailPlugin {
 	 * @param portalName
 	 * @param senderEmail
 	 */
-	public void sendNotification(Notification notification2Save, String vreName,	String portalName, String senderEmail, String ... hashtags)  {
+	public void sendNotification(Notification notification2Save, String vreName, String portalName, String senderEmail, String ... hashtags)  {
 		EmailNotificationProducer thread = new EmailNotificationProducer(new NotificationMail(notification2Save, vreName, portalName, senderEmail, hashtags));
 		thread.start();
 	}
@@ -210,7 +226,7 @@ public class EmailPlugin {
 		String portalUrl = null;
 		try {
 			user = UserLocalServiceUtil.getUserByScreenName(OrganizationsUtil.getCompany().getCompanyId(), notification2Save.getUserid());
-			portalUrl = PortalUtil.getPortalURL(OrganizationsUtil.getCompany().getVirtualHost(), PortalUtil.getPortalPort(), true);
+			portalUrl = PortalUtil.getPortalURL(OrganizationsUtil.getCompany().getVirtualHost(), 443, true);
 		} catch (Exception e1) {
 			e1.printStackTrace();
 			_log.warn("While trying to get email for user/group: " + notification2Save.getUserid());
@@ -220,7 +236,13 @@ public class EmailPlugin {
 
 		Message msg2Return = new MimeMessage(session);
 
-
+		if (notification2Save.getType() == NotificationType.POST_ALERT || 
+				notification2Save.getType() == NotificationType.COMMENT || 
+				notification2Save.getType() == NotificationType.MENTION ||  
+				notification2Save.getType() == NotificationType.OWN_COMMENT) {
+			String[] splits = senderEmail.split("@");
+			senderEmail = splits[0] + "+" + notification2Save.getSubjectid()  + "@" + splits[1];
+		}
 		// EMAIL SENDER
 		msg2Return.setHeader("Content-Type", "text/html; charset=UTF-8");
 		msg2Return.setFrom(new InternetAddress(senderEmail, portalName));
@@ -316,6 +338,12 @@ public class EmailPlugin {
 			return vreName +": Edited event in a shared calendar";
 		case CALENDAR_DELETED_EVENT:
 			return vreName +": Deleted in a shared calendar";
+		case TDM_TAB_RESOURCE_SHARE:
+			return notification2Save.getSenderFullName() + " shared a Tabular Resource with you on " + vreName;
+		case TDM_RULE_SHARE:
+			return notification2Save.getSenderFullName() + " shared a Tabular Data Manager Rule with you on " + vreName;
+		case TDM_TEMPLATE_SHARE:
+			return notification2Save.getSenderFullName() + " shared a Tabular Data Manager Template with you on " + vreName;
 		default:
 			return "You have a new Notification";
 		}
@@ -334,82 +362,89 @@ public class EmailPlugin {
 
 		switch (notification2Save.getType()) {
 		case LIKE:		
-			actionLink.append("\">.").append(" See the Post").append("</a>");
+			actionLink.append("\">").append(" See the Post").append("</a>");
 			break;
 		case COMMENT:
-			actionLink.append("\">.").append(" See the Post").append("</a>");
+			actionLink.append("\">").append(" See the Post").append("</a>");
 			break;
 		case MENTION:
-			actionLink.append("\">.").append(" See the Post").append("</a>");
+			actionLink.append("\">").append(" See the Post").append("</a>");
 			break;
 		case MESSAGE:
-			actionLink.append("\">.").append(" Go to Message").append("</a>");
+			actionLink.append("\">").append(" Go to Message").append("</a>");
 			break;
 		case WP_FOLDER_ADDEDUSER:
-			actionLink.append("\">.").append(" Go to Folder").append("</a>");
+			actionLink.append("\">").append(" Go to Folder").append("</a>");
 			break;
 		case WP_FOLDER_REMOVEDUSER:
-			actionLink.append("\">.").append(" Go to Folder").append("</a>");
+			actionLink.append("\">").append(" Go to Folder").append("</a>");
 			break;
 		case WP_FOLDER_SHARE:
-			actionLink.append("\">.").append(" Go to Folder").append("</a>");
+			actionLink.append("\">").append(" Go to Folder").append("</a>");
 			break;
 		case WP_ITEM_NEW:
-			actionLink.append("\">.").append(" Go to Folder").append("</a>");
+			actionLink.append("\">").append(" Go to Folder").append("</a>");
 			break;
 		case WP_ITEM_DELETE:
-			actionLink.append("\">.").append(" Go to Folder").append("</a>");
+			actionLink.append("\">").append(" Go to Folder").append("</a>");
 			break;
 		case WP_ITEM_UPDATED:
-			actionLink.append("\">.").append(" Go to Folder").append("</a>");
+			actionLink.append("\">").append(" Go to Folder").append("</a>");
 			break;
 		case OWN_COMMENT:
-			actionLink.append("\">.").append(" See the Post").append("</a>");
+			actionLink.append("\">").append(" See the Post").append("</a>");
 			break;
 		case POST_ALERT:
 			actionLink.append("\">").append("See this News").append("</a>");
 			break;
 		case REQUEST_CONNECTION:
-			actionLink.append("\">.").append(" Go to Contacts Center").append("</a>");
+			actionLink.append("\">").append(" Go to Contacts Center").append("</a>");
 			break;
 		case JOB_COMPLETED_NOK:
-			actionLink.append("\">.").append(" Go to Application").append("</a>");
+			actionLink.append("\">").append(" Go to Application").append("</a>");
 			break;
 		case JOB_COMPLETED_OK:
-			actionLink.append("\">.").append(" Go to Application").append("</a>");
+			actionLink.append("\">").append(" Go to Application").append("</a>");
 			break;
 		case DOCUMENT_WORKFLOW_EDIT:
-			actionLink.append("\">.").append(" Go to Document Workflow Manager").append("</a>");
+			actionLink.append("\">").append(" Go to Document Workflow Manager").append("</a>");
 			break;
 		case DOCUMENT_WORKFLOW_VIEW:
-			actionLink.append("\">.").append(" Go to Document Workflow Manager").append("</a>");
+			actionLink.append("\">").append(" Go to Document Workflow Manager").append("</a>");
 			break;
 		case DOCUMENT_WORKFLOW_STEP_REQUEST_TASK:
-			actionLink.append("\">.").append(" Go to Your Document Workflows").append("</a>");
+			actionLink.append("\">").append(" Go to Your Document Workflows").append("</a>");
 			break;
 		case DOCUMENT_WORKFLOW_FIRST_STEP_REQUEST_INVOLVMENT:
-			actionLink.append("\">.").append(" Go to Your Document Workflows").append("</a>");
+			actionLink.append("\">").append(" Go to Your Document Workflows").append("</a>");
 			break;
 		case DOCUMENT_WORKFLOW_USER_FORWARD_TO_OWNER:
-			actionLink.append("\">.").append(" Go to Document Workflow Manager").append("</a>");
+			actionLink.append("\">").append(" Go to Document Workflow Manager").append("</a>");
 			break;
 		case DOCUMENT_WORKFLOW_STEP_FORWARD_PEER:
-			actionLink.append("\">.").append(" Go to Document Workflow Manager").append("</a>");
+			actionLink.append("\">").append(" Go to Document Workflow Manager").append("</a>");
 			break;
 		case DOCUMENT_WORKFLOW_FORWARD_STEP_COMPLETED_OWNER:
-			actionLink.append("\">.").append(" Go to Document Workflow Manager").append("</a>");
+			actionLink.append("\">").append(" Go to Document Workflow Manager").append("</a>");
 			break;
 		case CALENDAR_ADDED_EVENT:
-			actionLink.append("\">.").append(" Go to Calendar").append("</a>");
+			actionLink.append("\">").append(" Go to Calendar").append("</a>");
 			break;
 		case CALENDAR_UPDATED_EVENT:
-			actionLink.append("\">.").append(" Go to Calendar").append("</a>");
+			actionLink.append("\">").append(" Go to Calendar").append("</a>");
 			break;
 		case CALENDAR_DELETED_EVENT:
-			actionLink.append("\">.").append(" Go to Calendar").append("</a>");
+			actionLink.append("\">").append(" Go to Calendar").append("</a>");
+			break;
+		case TDM_TAB_RESOURCE_SHARE:
+			actionLink.append("\">").append(" See this Tabular Resource").append("</a>");
+			break;
+		case TDM_RULE_SHARE:
+		case TDM_TEMPLATE_SHARE:			
+			actionLink.append("\">").append(" Go to Tabular Data Manager").append("</a>");
 			break;
 		default:
-			actionLink.append("\">.").append("").append("</a>");
+			actionLink.append("\">").append("").append("</a>");
 			break;			
 		}
 
